@@ -42,13 +42,13 @@ impl<'de> de::Visitor<'de> for SimpleVisitor {
 /// Methods used to encode the KEY.
 pub trait KeyEn: Serialize + Sized {
     /// Encode original key type to bytes.
-    #[cfg(all(feature = "cbor_codec", not(feature = "bcs_codec")))]
+    #[cfg(all(feature = "msgpack_codec", not(feature = "bcs_codec")))]
     fn encode_key(&self) -> RawBytes {
-        serde_cbor::to_vec(self).unwrap().into_boxed_slice()
+        msgpack::to_vec(self).unwrap().into_boxed_slice()
     }
 
     /// Encode original key type to bytes.
-    #[cfg(all(feature = "bcs_codec", not(feature = "cbor_codec")))]
+    #[cfg(all(feature = "bcs_codec", not(feature = "msgpack_codec")))]
     fn encode_key(&self) -> RawBytes {
         bcs::to_bytes(self).unwrap().into_boxed_slice()
     }
@@ -57,13 +57,13 @@ pub trait KeyEn: Serialize + Sized {
 /// Methods used to decode the KEY.
 pub trait KeyDe: DeserializeOwned {
     /// Decode from bytes to the original key type.
-    #[cfg(all(feature = "cbor_codec", not(feature = "bcs_codec")))]
+    #[cfg(all(feature = "msgpack_codec", not(feature = "bcs_codec")))]
     fn decode_key(bytes: &[u8]) -> Result<Self> {
-        serde_cbor::from_slice(bytes).c(d!())
+        msgpack::from_slice(bytes).c(d!())
     }
 
     /// Decode from bytes to the original key type.
-    #[cfg(all(feature = "bcs_codec", not(feature = "cbor_codec")))]
+    #[cfg(all(feature = "bcs_codec", not(feature = "msgpack_codec")))]
     fn decode_key(bytes: &[u8]) -> Result<Self> {
         bcs::from_bytes(bytes).c(d!())
     }
@@ -85,13 +85,13 @@ pub trait KeyEnDe: KeyEn + KeyDe {
 /// Methods used to encode the VALUE.
 pub trait ValueEn: Serialize + Sized {
     /// Encode original key type to bytes.
-    #[cfg(all(feature = "cbor_codec", not(feature = "bcs_codec")))]
+    #[cfg(all(feature = "msgpack_codec", not(feature = "bcs_codec")))]
     fn encode_value(&self) -> RawBytes {
-        serde_cbor::to_vec(self).unwrap().into_boxed_slice()
+        msgpack::to_vec(self).unwrap().into_boxed_slice()
     }
 
     /// Encode original key type to bytes.
-    #[cfg(all(feature = "bcs_codec", not(feature = "cbor_codec")))]
+    #[cfg(all(feature = "bcs_codec", not(feature = "msgpack_codec")))]
     fn encode_value(&self) -> RawBytes {
         bcs::to_bytes(self).unwrap().into_boxed_slice()
     }
@@ -100,13 +100,13 @@ pub trait ValueEn: Serialize + Sized {
 /// Methods used to decode the VALUE.
 pub trait ValueDe: DeserializeOwned {
     /// Decode from bytes to the original key type.
-    #[cfg(all(feature = "cbor_codec", not(feature = "bcs_codec")))]
+    #[cfg(all(feature = "msgpack_codec", not(feature = "bcs_codec")))]
     fn decode_value(bytes: &[u8]) -> Result<Self> {
-        serde_cbor::from_slice(bytes).c(d!())
+        msgpack::from_slice(bytes).c(d!())
     }
 
     /// Decode from bytes to the original key type.
-    #[cfg(all(feature = "bcs_codec", not(feature = "cbor_codec")))]
+    #[cfg(all(feature = "bcs_codec", not(feature = "msgpack_codec")))]
     fn decode_value(bytes: &[u8]) -> Result<Self> {
         bcs::from_bytes(bytes).c(d!())
     }
@@ -135,12 +135,12 @@ impl<T: KeyEn + KeyDe> KeyEnDe for T {}
 impl<T: ValueEn + ValueDe> ValueEnDe for T {}
 
 // used to encode the deref value of `Option<Box<[u8]>>`
-#[cfg(all(feature = "cbor_codec", not(feature = "bcs_codec")))]
+#[cfg(all(feature = "msgpack_codec", not(feature = "bcs_codec")))]
 pub(crate) fn encode_optioned_bytes(v: &Option<&[u8]>) -> RawBytes {
-    serde_cbor::to_vec(v).unwrap().into_boxed_slice()
+    msgpack::to_vec(v).unwrap().into_boxed_slice()
 }
 
-#[cfg(all(feature = "bcs_codec", not(feature = "cbor_codec")))]
+#[cfg(all(feature = "bcs_codec", not(feature = "msgpack_codec")))]
 pub(crate) fn encode_optioned_bytes(v: &Option<&[u8]>) -> RawBytes {
     bcs::to_bytes(v).unwrap().into_boxed_slice()
 }
